==> linkedin-job-profile-scraper-with-python-1.0.0.tar.gz: linkedin-job-profile-scraper-with-python-1.0.0/README.md <==
Linkedin-Job-Profile-Scraper-With-Python is a python library to scrape job profile data on linkedin using browser automation. 
It currently runs only on windows.

### Example
In this example we first import library, then we login with cookies and then scrape data.
```sh
from linkedin_job_profile_scraper_with_python import *
true=True;false=False
list_of_cookies=[
{
    "domain": ".linkedin.com",
    "expirationDate": 1676463230,
    "hostOnly": false,
    "httpOnly": false,
    "name": "_ga",
    "path": "/",
    "sameSite": "unspecified",
    "secure": false,
    "session": false,
    "storeId": "0",
    "value": "GA1.2.1029585723.1610264105",
    "id": 1
}]
#please replace the above sample cookies with your cookies, can see below link of how to fetch cookies
linkedin.login_cookie(cookies=list_of_cookies)
response=linkedin.get_job_profile(job_link='https://www.linkedin.com/jobs/view/2369119694/?refId=TtFWnJnfJ4Zg%2F7ciLoxuCA%3D%3D&trackingId=31e0gMvAc9LuFj7FH%2BPNgA%3D%3D&trk=flagship3_search_srp_jobs&lipi=urn%3Ali%3Apage%3Ad_flagship3_search_srp_jobs%3Bu6BQrVNCQYmzmhOzbcW9dg%3D%3D&lici=31e0gMvAc9LuFj7FH%2BPNgA%3D%3D')
data=response['body']
```

This module depends on the following python modules
* [requests](https://pypi.org/project/requests/)
* [btstudio](https://pypi.org/project/btstudio/)

#### BotStudio
[btstudio](https://pypi.org/project/btstudio/) is needed for browser automation. As soon as this library is imported in code, automated browser will open up. Complete documentation for Linkedin Automation available [here](https://linkedin-api.datakund.com/en/latest/)

### Installation

```sh
pip install linkedin-job-profile-scraper-with-python
```

### Import
```sh
from linkedin_job_profile_scraper_with_python import *
```

### Login with credentials
```sh
linkedin.login(username="linkedin username",password="linkedin password")
```

### Login with cookies
```sh
linkedin.login_cookie(cookies=list_of_cookies)
```

### Get job data
```sh
response=linkedin.get_job_profile(job_link='job_link')
data=response['body']
```

### Send Feedback to Developers
```sh
btstudio.send_feedback(feedback="Need help with this ......")
```

### Cookies
To login with cookies [Edit this Cookie Extension](https://chrome.google.com/webstore/detail/editthiscookie/fngmhnnpilhplaeedifhccceomclgfbg?hl=en) can be added to browser. Please check [this](https://abhishek-chaudhary.medium.com/how-to-get-cookies-of-any-website-from-browser-22b3d6348ed2) link how to get cookies to login to your linkedin.

### Contact Us
* [Telegram](https://t.me/datakund)
* [Website](https://datakund.com)

==> linkedin-job-profile-scraper-with-python-1.0.1.tar.gz: linkedin-job-profile-scraper-with-python-1.0.1/README.md <==
Linkedin-Job-Profile-Scraper-With-Python is a python library to scrape job profile data on linkedin using browser automation. 
It currently runs only on windows.

### Example
In this example we first import library, then we login with cookies and then scrape data.
```sh
from linkedin_job_profile_scraper_with_python import *
true=True;false=False
list_of_cookies=[
{
    "domain": ".linkedin.com",
    "expirationDate": 1676463230,
    "hostOnly": false,
    "httpOnly": false,
    "name": "_ga",
    "path": "/",
    "sameSite": "unspecified",
    "secure": false,
    "session": false,
    "storeId": "0",
    "value": "GA1.2.1029585723.1610264105",
    "id": 1
}]
#please replace the above sample cookies with your cookies, can see below link of how to fetch cookies
linkedin.login_cookie(cookies=list_of_cookies)
response=linkedin.get_job_profile(job_link='https://www.linkedin.com/jobs/view/2369119694/?refId=TtFWnJnfJ4Zg%2F7ciLoxuCA%3D%3D&trackingId=31e0gMvAc9LuFj7FH%2BPNgA%3D%3D&trk=flagship3_search_srp_jobs&lipi=urn%3Ali%3Apage%3Ad_flagship3_search_srp_jobs%3Bu6BQrVNCQYmzmhOzbcW9dg%3D%3D&lici=31e0gMvAc9LuFj7FH%2BPNgA%3D%3D')
data=response['body']
```

This module depends on the following python modules
* [requests](https://pypi.org/project/requests/)
* [bot_studio](https://pypi.org/project/bot_studio/)

#### BotStudio
[bot_studio](https://pypi.org/project/bot_studio/) is needed for browser automation. As soon as this library is imported in code, automated browser will open up. Complete documentation for Linkedin Automation available [here](https://linkedin-api.datakund.com/en/latest/)

### Installation

```sh
pip install linkedin-job-profile-scraper-with-python
```

### Import
```sh
from linkedin_job_profile_scraper_with_python import *
```

### Login with credentials
```sh
linkedin.login(username="linkedin username",password="linkedin password")
```

### Login with cookies
```sh
linkedin.login_cookie(cookies=list_of_cookies)
```

### Get job data
```sh
response=linkedin.get_job_profile(job_link='job_link')
data=response['body']
```

### Send Feedback to Developers
```sh
bot_studio.send_feedback(feedback="Need help with this ......")
```

### Cookies
To login with cookies [Edit this Cookie Extension](https://chrome.google.com/webstore/detail/editthiscookie/fngmhnnpilhplaeedifhccceomclgfbg?hl=en) can be added to browser. Please check [this](https://abhishek-chaudhary.medium.com/how-to-get-cookies-of-any-website-from-browser-22b3d6348ed2) link how to get cookies to login to your linkedin.

### Contact Us
* [Telegram](https://t.me/datakund)
* [Website](https://datakund.com)
